==========
atomate
==========

atomate is a powerful software for computational materials science and contains pre-built workflows.

For more about atomate, please visit the official documentation_.

.. _documentation: http://packages.python.org/atomate/
